@@ -1,6 +1,7 @@
 import pandas as pd
 import numpy as np
 from sklearn.metrics import get_scorer, SCORERS, make_scorer
+from scipy.stats import spearmanr
 
 def binary_returns_metric_fn(y_true: pd.DataFrame, y_pred: np.array):
     assert len(y_true.columns) == 1
@@ -22,10 +23,23 @@ def binary_returns_avg_metric_fn(y_true: pd.DataFrame, y_pred: np.array):
 
     return score
 
+def regression_corr(y_true: pd.DataFrame, y_pred: np.array):
+    assert len(y_true.columns) == 1
+    assert np.all((y_pred == 0) | (y_pred == 1)), "predictions must be either 0 or 1"
+
+    coef, p = spearmanr(y_true, y_pred)
+    score = 0
+
+    if p <= 0.05:
+        score = coef
+
+    return score
+
 
 CUSTOM_SCORERS = dict(
     binary_returns=make_scorer(binary_returns_metric_fn),
     binary_returns_avg=make_scorer(binary_returns_avg_metric_fn),
+    regression_corr=make_scorer(regression_corr)
 )
 
 
